==> drd-8.x-3.0.tar.gz: drd/src/Plugin/Block/WidgetQueue.php <==
<?php

namespace Drupal\drd\Plugin\Block;

use Drupal\Core\Annotation\Translation;
use Drupal\Core\Block\Annotation\Block;
use Drupal\Core\Url;
use Drupal\queue_ui\QueueUI;

/**
 * Provides a 'WidgetQueue' block.
 *
 * @Block(
 *  id = "drd_queue",
 *  admin_label = @Translation("DRD Queue"),
 *  weight = -3,
 *  tags = {"drd_widget"},
 * )
 */
class WidgetQueue extends Base {

  /**
   * {@inheritdoc}
   */
  public function build() {
    $build = [];

    $c = \Drupal::service('queue.drd')->countItems();
    if (empty($c)) {
      $message = $this->t('<p>Your queue is empty.</p>');
    }
    else {
      $message = $this->t('<p class="message">You have %count action in your queue.</p>', ['%count' => $c]);
      $message .= $this->t('<p>Actions from the queue will be executed:</p><ul>');
      $message .= $this->t('<li>next time cron is being executed</li>');
      $message .= $this->t('<li>by <a href="@cron">running cron</a> now</li>', ['@cron' => (new Url('system.cron', ['key' => \Drupal::state()->get('system.cron_key')]))->toString()]);
      if (\Drupal::moduleHandler()->moduleExists('queue_ui')) {
        $message .= $this->t('<li>by <a href="@queueui">batch processing</a> the queue</li>', ['@queueui' => (new Url('queue_ui.overview_form'))->toString()]);
      }
      else {
        $message .= $this->t('<li>(The module <a href="https://www.drupal.org/project/queue_ui">Queue UI</a> is not installed but recommended.)</li>');
      }
      $message .= '</ul>';
    }
    $build['drd_queue']['#markup'] = $message;

    return $build;
  }

}

==> drd-8.x-3.3.tar.gz: drd/src/Plugin/Block/WidgetQueue.php <==
<?php

namespace Drupal\drd\Plugin\Block;

use Drupal\Core\Annotation\Translation;
use Drupal\Core\Block\Annotation\Block;
use Drupal\Core\Url;
use Drupal\queue_ui\QueueUI;

/**
 * Provides a 'WidgetQueue' block.
 *
 * @Block(
 *  id = "drd_queue",
 *  admin_label = @Translation("DRD Queue"),
 *  weight = -3,
 *  tags = {"drd_widget"},
 * )
 */
class WidgetQueue extends WidgetBase {

  protected function title() {
    return $this->t('Action Queue');
  }

  protected function message() {
    $c = \Drupal::service('queue.drd')->countItems();
    if (empty($c)) {
      $message = $this->t('<p>Your queue is empty.</p>');
    }
    else {
      $message = $this->t('<p class="message">You have %count action in your queue.</p>', ['%count' => $c]);
      $message .= $this->t('<p>Actions from the queue will be executed:</p><ul>');
      $message .= $this->t('<li>next time cron is being executed</li>');
      $message .= $this->t('<li>by <a href="@cron">running cron</a> now</li>', ['@cron' => (new Url('system.cron', ['key' => \Drupal::state()->get('system.cron_key')]))->toString()]);
      if (\Drupal::moduleHandler()->moduleExists('queue_ui')) {
        $message .= $this->t('<li>by <a href="@queueui">batch processing</a> the queue</li>', ['@queueui' => (new Url('queue_ui.overview_form'))->toString()]);
      }
      else {
        $message .= $this->t('<li>(The module <a href="https://www.drupal.org/project/queue_ui">Queue UI</a> is not installed but recommended.)</li>');
      }
      $message .= '</ul>';
    }

    return $message;
  }

}
